﻿Imports System.Collections.ObjectModel

Imports MindFusion.Charting
Imports MindFusion.Charting.Components
Imports MindFusion.Drawing

Imports Color = System.Drawing.Color

Public Class MainForm

	Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		' create sample data
		bubbleChart.Series = GetSeriesCollection()

		' axis titles and ranges
		bubbleChart.XAxis.Title = "Average relative annual growth (%)"
		bubbleChart.XAxis.MinValue = -1
		bubbleChart.XAxis.MaxValue = 1
		bubbleChart.YAxis.Title = "July 1, 2015 projection"
		bubbleChart.YAxis.MinValue = 0
		bubbleChart.YAxis.MaxValue = 100

		' background appearance
		bubbleChart.ShowZoomWidgets = True
		bubbleChart.Theme.LegendBackground = New SolidBrush(Color.Black)
		bubbleChart.GridType = GridType.Vertical
		bubbleChart.BackColor = Color.FromArgb(45, 57, 86)
		bubbleChart.Theme.GridColor1 = Color.FromArgb(100, 0, 52, 102)
		bubbleChart.Theme.GridColor2 = Color.FromArgb(200, 0, 52, 102)
		bubbleChart.Theme.LegendBackground = New SolidBrush(Color.FromArgb(0, 52, 102))

		' series colors
		bubbleChart.Theme.CommonSeriesFills = New List(Of Brush)() From {
			New LinearGradientBrush(Color.Transparent, Color.FromArgb(156, 170, 198)),
			New LinearGradientBrush(Color.Transparent, Color.FromArgb(206, 0, 0))
		}
		bubbleChart.Theme.UniformSeriesStroke = New SolidBrush(Color.White)
		bubbleChart.Theme.HighlightStroke = New SolidBrush(Color.White)
		bubbleChart.Theme.DataLabelsBrush = New SolidBrush(Color.White)
		bubbleChart.Theme.LegendTitleBrush = New SolidBrush(Color.White)
		bubbleChart.Theme.LegendBorderStroke = New SolidBrush(Color.White)
		bubbleChart.Theme.AxisLabelsBrush = New SolidBrush(Color.White)
		bubbleChart.Theme.AxisTitleBrush = New SolidBrush(Color.White)
		bubbleChart.Theme.AxisStroke = New SolidBrush(Color.White)

		bubbleChart.Theme.HighlightStrokeDashStyle = System.Drawing.Drawing2D.DashStyle.Dot

		SetupControls()

	End Sub

	Private Sub SetupControls()
		cbGridType.SelectedIndex = CInt(bubbleChart.GridType)
		cbPinGrid.Checked = bubbleChart.PinGrid
		cbShowScatter.Checked = bubbleChart.ShowScatter
		cbShowX.Checked = bubbleChart.ShowXCoordinates
		cbShowY.Checked = bubbleChart.ShowYCoordinates
		cbShowXTicks.Checked = bubbleChart.ShowXTicks
		cbShowYTicks.Checked = bubbleChart.ShowYTicks
		cbAllowPan.Checked = bubbleChart.AllowPan
		cbMoveLegend.Checked = bubbleChart.AllowMoveLegend
		cbHorAlign.SelectedIndex = CInt(bubbleChart.LegendHorizontalAlignment)
		cbVertAlign.SelectedIndex = CInt(bubbleChart.LegendVerticalAlignment)
		tbMarginLeft.Minimum = 0
		tbMarginLeft.Maximum = bubbleChart.Width - 100
		tbMarginLeft.Value = CInt(bubbleChart.LegendMargin.Left)
		tbMarginTop.Minimum = 0
		tbMarginTop.Maximum = bubbleChart.Height - 100
		tbMarginTop.Value = CInt(bubbleChart.LegendMargin.Top)
		cbShowLabels.Checked = True
		cbLegend.Checked = True
		cbWidgets.Checked = bubbleChart.ShowZoomWidgets
	End Sub

	Private Function GetSeriesCollection() As ObservableCollection(Of Series)
		' bubble chart requires three dimensional data;
		' two dimensions for position and one for size
		Dim series3D1 = New PointSeries3D(New List(Of Point3D)() From { _
		 New Point3D(0.32F, 81, 9.5F * 10), _
		 New Point3D(0.39F, 66, 7.8F * 10), _
		 New Point3D(0.75F, 65, 7.6F * 10), _
		 New Point3D(0.49F, 60, 7.1F * 10) _
		}, New List(Of String)() From { _
		 "Germany", _
		 "France", _
		 "UK", _
		 "Italy" _
		})
		series3D1.Title = ">50 000 000"

		Dim series3D2 = New PointSeries3D(New List(Of Point3D)() From { _
		 New Point3D(-0.28F, 46, 5.4F * 10), _
		 New Point3D(-0.32F, 42, 5 * 10), _
		 New Point3D(0.05F, 38, 4.5F * 10), _
		 New Point3D(-0.4F, 19, 2.3F * 10) _
		}, New List(Of String)() From { _
		 "Spain", _
		 "Ukraine", _
		 "Poland", _
		 "Romania" _
		})
		series3D2.Title = "<50 000 000"

		Dim data = New ObservableCollection(Of Series)()
		data.Add(series3D1)
		data.Add(series3D2)

		Return data
	End Function

	Private Sub cbGridType_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cbGridType.SelectedIndexChanged
		bubbleChart.GridType = DirectCast(cbGridType.SelectedIndex, GridType)
	End Sub

	Private Sub cbPinGrid_CheckedChanged(sender As Object, e As EventArgs) Handles cbPinGrid.CheckedChanged
		bubbleChart.PinGrid = cbPinGrid.Checked
	End Sub

	Private Sub cbShowScatter_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowScatter.CheckedChanged
		bubbleChart.ShowScatter = cbShowScatter.Checked
	End Sub

	Private Sub cbShowX_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowX.CheckedChanged
		bubbleChart.ShowXCoordinates = cbShowX.Checked
	End Sub

	Private Sub cbShowY_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowY.CheckedChanged
		bubbleChart.ShowYCoordinates = cbShowY.Checked
	End Sub

	Private Sub cbShowXTicks_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowXTicks.CheckedChanged
		bubbleChart.ShowXTicks = cbShowXTicks.Checked
	End Sub

	Private Sub cbShowYTicks_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowYTicks.CheckedChanged
		bubbleChart.ShowYTicks = cbShowYTicks.Checked
	End Sub

	Private Sub cbAllowPan_CheckedChanged(sender As Object, e As EventArgs) Handles cbAllowPan.CheckedChanged
		bubbleChart.AllowPan = cbAllowPan.Checked
	End Sub

	Private Sub cbMoveLegend_CheckedChanged(sender As Object, e As EventArgs) Handles cbMoveLegend.CheckedChanged
		bubbleChart.AllowMoveLegend = cbMoveLegend.Checked
	End Sub

	Private Sub cbHorAlign_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cbHorAlign.SelectedIndexChanged
		bubbleChart.LegendHorizontalAlignment = DirectCast(cbHorAlign.SelectedIndex, LayoutAlignment)
	End Sub

	Private Sub cbVertAlign_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cbVertAlign.SelectedIndexChanged
		bubbleChart.LegendVerticalAlignment = DirectCast(cbVertAlign.SelectedIndex, LayoutAlignment)
	End Sub

	Private Sub tbMarginLeft_Scroll(sender As Object, e As EventArgs) Handles tbMarginLeft.Scroll
		bubbleChart.LegendMargin = New Margins(tbMarginLeft.Value, bubbleChart.LegendMargin.Top, 0, 0)
	End Sub

	Private Sub tbMarginTop_Scroll(sender As Object, e As EventArgs) Handles tbMarginTop.Scroll
		bubbleChart.LegendMargin = New Margins(bubbleChart.LegendMargin.Left, tbMarginTop.Value, 0, 0)
	End Sub

	Private Sub cbShowLabels_CheckedChanged(sender As Object, e As EventArgs) Handles cbShowLabels.CheckedChanged
		If cbShowLabels.Checked Then
			bubbleChart.ShowDataLabels = bubbleChart.ShowDataLabels Or LabelKinds.InnerLabel
		Else
			bubbleChart.ShowDataLabels = bubbleChart.ShowDataLabels Xor LabelKinds.InnerLabel
		End If
		bubbleChart.Invalidate()
	End Sub

	Private Sub cbLegend_CheckedChanged(sender As Object, e As EventArgs) Handles cbLegend.CheckedChanged
		bubbleChart.ShowLegend = cbLegend.Checked
	End Sub

	Private Sub cbWidgets_CheckedChanged(sender As Object, e As EventArgs) Handles cbWidgets.CheckedChanged
		bubbleChart.ShowZoomWidgets = cbWidgets.Checked
	End Sub


End Class
